/**
******************************************************************************
* @file    queue.c
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief   IRPyro evaluation tool with API integration.
* @verbatim
 ===============================================================================
                      ##### Description #####
 ===============================================================================
  [..]
  [..]
 @endverbatim
  ******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>
   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim

  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "queue.h"
/**
 * @addtogroup Queue_Handler
 * @{
*/
/** @defgroup queue Queue
  * Queue structure definition. Adds and removes elements.
  * @brief Circular queue functions
  * @verbatim
  *
  * @endverbatim
  * @note
  * @{
  */
/**
  * @brief  Checks is the queue is full
  * @param  q      Circular buffer
  */
int message_queue_full(volatile struct Queue *q)
{
    return (((q->pWR + 1) % QUEUE_SIZE) == q->pRD);
}
/**
  * @brief  Checks if the queue is empty
  * @param  q      Circular buffer
  */
int message_queue_empty(volatile struct Queue *q)
{
    return (q->pWR == q->pRD);
}
/**
  * @brief  Adds a byte to the circular buffer
  * @param  q      Circular buffer
  * @param  data   Byte to be added to the queue
  */
int message_enqueue(volatile struct Queue *q, uint8_t data)
{
    if (message_queue_full(q))
        return 0;
    else
    {
        q->q[q->pWR] = data;
        if ((q->pWR + 1) == QUEUE_SIZE)
        {
            q->pWR = 0;
        }
        else
        {
            ++ q->pWR;
        }
    }
    return 1;
}
/**
  * @brief  Obtains one byte from the circular buffer
  * @param  q      Circular buffer
  * @param  data   Byte to be removed from the queue
  */
int message_dequeue(volatile struct Queue *q, uint8_t *data)
{
    if (message_queue_empty(q))
        return 0;
    else
    {
        *data = q->q[q->pRD];
        if ((q->pRD + 1) == QUEUE_SIZE)
        {
            q->pRD = 0;
        }
        else
        {
            ++ q->pRD;
        }
    }
    return 1;
}
/** end defgroup queue
  * @}
  */
/** end of addtogroup Queue_Handler
 * @}
*/
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
